package com.ruoyi.invest.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.invest.domain.TProjectScoring;

/**
 * 打分Service接口
 * 
 * @author ruoyi
 * @date 2024-02-23
 */
public interface ITProjectScoringService 
{
    /**
     * 查询打分
     * 
     * @param id 打分主键
     * @return 打分
     */
    public TProjectScoring selectTProjectScoringById(String id);

    /**
     * 查询打分列表
     * 
     * @param tProjectScoring 打分
     * @return 打分集合
     */
    public List<TProjectScoring> selectTProjectScoringList(TProjectScoring tProjectScoring);

    /**
     * 新增打分
     * 
     * @param tProjectScoring 打分
     * @return 结果
     */
    public int insertTProjectScoring(TProjectScoring tProjectScoring);

    /**
     * 修改打分
     * 
     * @param tProjectScoring 打分
     * @return 结果
     */
    public int updateTProjectScoring(TProjectScoring tProjectScoring);

    /**
     * 批量删除打分
     * 
     * @param ids 需要删除的打分主键集合
     * @return 结果
     */
    public int deleteTProjectScoringByIds(String[] ids);

    /**
     * 删除打分信息
     * 
     * @param id 打分主键
     * @return 结果
     */
    public int deleteTProjectScoringById(String id);

    /**
     * 批量删除打分(修改del_flag状态)
     *
     * @param ids 需要删除的打分主键集合
     * @return 结果
     */
    public int updateTProjectScoringByIds(String[] ids);

    /**
     * 根据会议ID查询汇总分数和平均分数
     * @param meetingId
     * @return
     */
    Map<String,String> selectMeetingId(String meetingId);

    /**
     * 根据会议ID和用户ID 查询打分数据
     * @param meetingId
     * @param userId
     * @return
     */
    TProjectScoring getCanScoringMeetingId(String meetingId, Long userId);

}
